@@ -111,16 +111,16 @@ class trsf_parameters(object):
         )
         output = "The registration will run with the following arguments:\n"
         output += "\n" + " File format ".center(max_tot, "-") + "\n"
-        output += "path_to_data".ljust(max_key, " ") + ": {:s}\n".format(
+        output += "path_to_data".ljust(max_key, " ") + ": {}\n".format(
             self.path_to_data
         )
-        output += "file_name".ljust(max_key, " ") + ": {:s}\n".format(
+        output += "file_name".ljust(max_key, " ") + ": {}\n".format(
             self.file_name
         )
-        output += "trsf_folder".ljust(max_key, " ") + ": {:s}\n".format(
+        output += "trsf_folder".ljust(max_key, " ") + ": {}\n".format(
             self.trsf_folder
         )
-        output += "output_format".ljust(max_key, " ") + ": {:s}\n".format(
+        output += "output_format".ljust(max_key, " ") + ": {}\n".format(
             self.output_format
         )
         output += "check_TP".ljust(max_key, " ") + ": {:d}\n".format(
@@ -141,10 +141,10 @@ class trsf_parameters(object):
                 self.ref_TP
             )
             if self.ref_path is not None:
-                output += "ref_path".ljust(max_key, " ") + ": {:s}\n".format(
+                output += "ref_path".ljust(max_key, " ") + ": {}\n".format(
                     self.ref_path
                 )
-            output += "trsf_type".ljust(max_key, " ") + ": {:s}\n".format(
+            output += "trsf_type".ljust(max_key, " ") + ": {}\n".format(
                 self.trsf_type
             )
             if self.trsf_type == "vectorfield":
@@ -178,10 +178,10 @@ class trsf_parameters(object):
             if self.projection_path is not None:
                 output += "projection_path".ljust(
                     max_key, " "
-                ) + ": {:s}\n".format(self.projection_path)
+                ) + ": {}\n".format(self.projection_path)
             output += "image_interpolation".ljust(
                 max_key, " "
-            ) + ": {:s}\n".format(self.image_interpolation)
+            ) + ": {}\n".format(self.image_interpolation)
 
         return output
 
@@ -199,9 +199,17 @@ class trsf_parameters(object):
         self.output_format = str(Path(prefix) / self.output_format) + path.sep
 
     def __init__(self, file_name: str):
-        with open(file_name) as f:
-            param_dict = json.load(f)
-            f.close()
+        if not isinstance(file_name, dict):
+            with open(file_name) as f:
+                param_dict = json.load(f)
+                f.close()
+        else:
+            param_dict = {}
+            for k, v in file_name.items():
+                if isinstance(v, Path):
+                    param_dict[k] = str(v)
+                else:
+                    param_dict[k] = v
 
         # Default parameters
         self.check_TP = None
@@ -567,31 +575,34 @@ class TimeRegistration:
         Returns:
             (list): list of `trsf_parameters` objects
         """
-        if p_param is None:
-            if len(sys.argv) < 2 or sys.argv[1] == '-f':
-                p_param = input(
-                    "\nPlease inform the path to the json config file:\n"
-                )
+        if not isinstance(p_param, dict):
+            if p_param is None:
+                if len(sys.argv) < 2 or sys.argv[1] == '-f':
+                    p_param = input(
+                        "\nPlease inform the path to the json config file:\n"
+                    )
+                else:
+                    p_param = sys.argv[1]
+            stable = False or isinstance(p_param, Path)
+            while not stable:
+                tmp = p_param.strip('"').strip("'").strip(" ")
+                stable = tmp == p_param
+                p_param = tmp
+            if os.path.isdir(p_param):
+                f_names = [
+                    os.path.join(p_param, f)
+                    for f in os.listdir(p_param)
+                    if ".json" in f and not "~" in f
+                ]
             else:
-                p_param = sys.argv[1]
-        stable = False or isinstance(p_param, Path)
-        while not stable:
-            tmp = p_param.strip('"').strip("'").strip(" ")
-            stable = tmp == p_param
-            p_param = tmp
-        if os.path.isdir(p_param):
-            f_names = [
-                os.path.join(p_param, f)
-                for f in os.listdir(p_param)
-                if ".json" in f and not "~" in f
-            ]
+                f_names = [p_param]
         else:
             f_names = [p_param]
-
         params = []
         for file_name in f_names:
-            print("")
-            print("Extraction of the parameters from file %s" % file_name)
+            if isinstance(file_name, str):
+                print("")
+                print("Extraction of the parameters from file %s" % file_name)
             p = trsf_parameters(file_name)
             if not p.check_parameters_consistancy():
                 print("\n%s Failed the consistancy check, it will be skipped")
@@ -1142,7 +1153,11 @@ class TimeRegistration:
     def __init__(self, params=None):
         if params is None:
             self.params = self.read_param_file()
-        elif isinstance(params, str) or isinstance(params, Path):
+        elif (
+            isinstance(params, str)
+            or isinstance(params, Path)
+            or isinstance(params, dict)
+            ):
             self.params = TimeRegistration.read_param_file(params)
         else:
             self.params = params
